@@ -1,7 +1,7 @@
 test_that("chronos works with supported formats", {
     time <- as.POSIXct("2024-02-26 13:14:00")
     fmt <- formats_lst[["datetime"]][!grepl("%Z", formats_lst[["datetime"]])]
-    times <- as.character(sapply(fmt, function(x) format(time, format = x), USE.NAMES = FALSE))
+    times <- unique(as.character(sapply(fmt, function(x) format(time, format = x), USE.NAMES = FALSE)))
     expect_true(all(chronos(times) == time))
 
     date <- as.Date("2024-02-26")
@@ -11,3 +11,8 @@ test_that("chronos works with supported formats", {
 
     expect_true(!any(is.na(chronos(bench_date))))
 })
+
+test_that("timezone conversion #14", {
+    res <- chronos(bench_date[5], tz = "CET", to_tz = "UTC")
+    expect_equal(res, as.POSIXct("2017-11-25 21:34:50", tz = "UTC"))
+})
